<?php

function stbl_get_related_entry($attributes)
{

	if ( ! is_single() ) return '';

	$selected_style = ! empty( $attributes["className"] ) ? $attributes["className"] : 'is-style-default';

	$classname = "wp-block-streetist-blocks-related-entry" . ' ' . $selected_style;

	$num = ( ! empty( $attributes['num'] ) && is_numeric( $attributes['num' ]) )
		? $attributes['num']
		: 5;

	if ( is_string($num) ) $num = intval( $num );

	global $post;

	if ( empty( $post ) ) return '';
	$current_post_id = $post->ID;
	$categories = get_the_category( $current_post_id );

	$category_id = array();
	foreach ( $categories as $category ) {
		array_push( $category_id, $category->cat_ID );
	}

	// 表示済みの投稿を格納していく
	$pickup_entries_id = array();

	$args = array(
		'post__not_in'    => array( $current_post_id ),
		'posts_per_page'  => $num,
		'category__in'    => $category_id,
		'orderby'         => 'rand',
		'meta_query'      => array(
			array(
				'key' => 'priority_post',
				'value'=> 'on'
			),
		),
	);

	$wp_query = new WP_Query($args);

	$count = 0;

	ob_start();

?>
	<div class="<?php echo $classname; ?>">
		<div class="stbl-related-entry">
			<?php
				// 優先記事から表示
				if ( $wp_query->have_posts() ) {
					while ( $wp_query->have_posts() ) {
						$wp_query->the_post();

						$post_id = get_the_ID();
						stbl_get_related_entry_item( $post_id, $selected_style );
						array_push( $pickup_entries_id, $post_id ); // 表示済みの投稿を格納していく
						$count++;
					}
				}

				// 足りなかったらランダムで表示
				if ( $count !== $num )  {
					array_push( $pickup_entries_id, $current_post_id );

					$args = array(
						'category__in'    => $category_id,
						'post__not_in' => $pickup_entries_id,
						'posts_per_page' => ($num - $count),
						'orderby' => 'rand',
					);

					$wp_query = new WP_Query($args);

					if ( $wp_query->have_posts() ) {
						while ( $wp_query->have_posts() ) {
							$wp_query->the_post();

							$post_id = get_the_ID();
							stbl_get_related_entry_item( $post_id, $selected_style );
						}
					}
				}
			
			?>
		</div>
	</div>
<?php
	$content = ob_get_clean();

	wp_reset_postdata();

	return $content;
}

function stbl_get_related_entry_item( $post_id, $selected_style ) {

	$title_length = $selected_style === 'is-style-default' ? 50 : 80;
	$title = get_the_title();
	$title = stbl_mb_substr_text( $title, $title_length );
	$thumb_data = $selected_style === 'is-style-default' ? stbl_get_thumbnail_info( $post_id, "medium_large" ) : null;
	$datetime = get_the_date( 'Y-m-d', $post_id );
	$time = get_the_date( 'Y.m.d', $post_id );
	?>
	<a href="<?php echo get_the_permalink(); ?>" class="stbl-related-entry__item">
		<article class="stbl-related-entry-card">
			<?php if ( $thumb_data && isset( $thumb_data[0] ) ): ?>
				<figure class="stbl-related-entry-card__thumb">
					<img src="<?php echo $thumb_data[0]; ?>" width="<?php echo $thumb_data[1]; ?>" height="<?php echo $thumb_data[2]; ?>" alt="<?php echo $title; ?>" loading="lazy" />
				</figure>
			<?php endif; ?>
			<div class="stbl-related-entry-card__content">
				<p class="stbl-related-entry-card__title">
					<?php echo $title; ?>
				</p>
				<p class="stbl-related-entry-card__date">
					<time datetime="<?php echo $datetime; ?>"><?php echo $time; ?></time>
				</p>
			</div>
		</article>
	</a>
	<?php
}

function stbl_register_block_related_entry() {
	register_block_type( 'streetist-blocks/related-entry', array(
		'editor_script' => 'editor-script-streetist-blocks',
		'editor_style' => 'editor-style-streetist-blocks',
		'script' => 'script-streetist-blocks',
		'style' => 'style-streetist-blocks',
		'attributes' 	=> array(
			'num'   => array(
				'type' => 'string',
			),
		),
		'render_callback' => 'stbl_get_related_entry',
	));
}
add_action( 'init', 'stbl_register_block_related_entry' );